@@ -1,12 +1,14 @@
-package MooseX::FileAttribute;
+package MooseX::FileAttribute; # git description: v0.02-3-g9511cc8
+# ABSTRACT: Sugar for classes that have file or directory attributes
+
 use strict;
 use warnings;
 use Moose::Exporter;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 use 5.008001;
 
-use MooseX::Types -declare => ['ExistingFile', 'ExistingDir'];
+use MooseX::Types 0.11 -declare => ['ExistingFile', 'ExistingDir'];
 use MooseX::Types::Moose qw(Str);
 use MooseX::Types::Path::Class qw(File Dir);
 
@@ -56,9 +58,17 @@ sub has_directory {
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
-MooseX::FileAttribute - sugar for classes that have file or directory attributes
+MooseX::FileAttribute - Sugar for classes that have file or directory attributes
+
+=head1 VERSION
+
+version 0.03
 
 =head1 SYNOPSIS
 
@@ -124,17 +134,40 @@ The ExistingFile constraint will accept named pipes, ttys,
 directories, etc., as files, as long as what's named exists on disk.
 The ExistingDir constraint is more strict, only allowing directories.
 
-=head1 REPOSITORY AND BUG TRACKER
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=MooseX-FileAttribute>
+(or L<bug-MooseX-FileAttribute@rt.cpan.org|mailto:bug-MooseX-FileAttribute@rt.cpan.org>).
 
-http://github.com/jrockway/moosex-fileattribute
+I am also usually active on irc, as 'ether' at C<irc.perl.org>.
 
 =head1 AUTHOR
 
-Jonathan Rockway C<< <jrockway@cpan.org> >>
+Jonathan Rockway <jrockway@cpan.org>
 
-=head1 COPYRIGHT
+=head1 CONTRIBUTORS
 
-Copyright (c) 2009 Jonathan Rockway.
+=for stopwords Karen Etheridge Jonathan Rockway Ken Crowell
 
-This module is Free software.  You can redistribute it under the same
-terms as Perl itself.
+=over 4
+
+=item *
+
+Karen Etheridge <ether@cpan.org>
+
+=item *
+
+Jonathan Rockway <jon@jrock.us>
+
+=item *
+
+Ken Crowell <ken@oeuftete.com>
+
+=back
+
+=head1 COPYRIGHT AND LICENCE
+
+This software is copyright (c) 2009 by Jonathan Rockway.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
